﻿using Infragistics.Controls.Charts;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace GetMarkerItem
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
             
            XamDataChart chart = new XamDataChart();
            chart.SeriesMouseLeftButtonDown += XamDataChart_SeriesMouseLeftButtonDown;
            chart.Axes.Add(new NumericXAxis());
            chart.Axes.Add(new NumericYAxis());


            FrameworkElementFactory factory = new FrameworkElementFactory(typeof(MarkerEditor));
            factory.SetValue(MarkerEditor.WidthProperty, 20.0);
            factory.SetValue(MarkerEditor.HeightProperty, 20.0);
            factory.SetValue(MarkerEditor.TargetPropertyNameProperty, "some");

            DataTemplate marker = new DataTemplate();
            marker.VisualTree = factory;

            ScatterLineSeries scatterSeries = new ScatterLineSeries
            {
                ItemsSource = ChartData.GenerateData(10),
                XAxis = chart.Axes[0] as NumericXAxis,
                YAxis = chart.Axes[1] as NumericYAxis,
                XMemberPath = "Index",
                YMemberPath = "Value1",
                MarkerTemplate = marker,
               
            };
            chart.Series.Add(scatterSeries);

            root.Children.Add(chart);
        }

        private void XamDataChart_SeriesMouseLeftButtonDown(object sender, Infragistics.Controls.Charts.DataChartMouseButtonEventArgs e)
        {
            if (e.Item != null)
            {
                MessageBox.Show((e.Item as ChartData).Index + "\n" + (e.Item as ChartData).Value1);
            }
        }
    }

    
    public class ChartData
    {
        public DateTime Date { get; set; }
        public int Index { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Index = 0,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(20, 40),
                Value3 = r.Next(20, 40),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddDays(i),
                    Index = i,
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }
				
}
